@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015 Canonical, Ltd.
+ * Copyright (C) 2015 Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 3, as published
@@ -21,7 +21,7 @@
 #include <QDBusObjectPath>
 #include <QObject>
 
-namespace ubuntu
+namespace ayatana
 {
 
 namespace indicators
@@ -47,4 +47,4 @@ public:
 
 } // namespace indicators
 
-} // namespace ubuntu
+} // namespace ayatana
